@@ -11,7 +11,7 @@ require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw(get_all_data get_all_postalcodes get_all_cities get_postalcode_from_city get_city_from_postalcode validate_postalcode validate);
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 sub get_all_data {
     my $validator = Class::Business::GL::Postalcode->new();
@@ -55,17 +55,21 @@ sub validate_postalcode {
 
 1;
 
+__END__
+
 =pod
 
-=begin HTML
+=begin markdown
 
-<a href="https://travis-ci.org/jonasbn/perl-Business-GL-Postalcode"><img src="https://travis-ci.org/jonasbn/perl-Business-GL-Postalcode.svg?branch=master"></a>
+[![CPAN version](https://badge.fury.io/pl/Business-GL-Postalcode.svg)](http://badge.fury.io/pl/Business-GL-Postalcode)
+[![Build Status](https://travis-ci.org/jonasbn/perl-Business-GL-Postalcode.svg?branch=master)](https://travis-ci.org/jonasbn/perl-Business-GL-Postalcode)
+[![Coverage Status](https://coveralls.io/repos/jonasbn/perl-Business-GL-Postalcode/badge.png)](https://coveralls.io/r/jonasbn/perl-Business-GL-Postalcode)
 
-=end HTML
+=end markdown
 
 =head1 NAME
 
-Business::GL::Postalcode - validation and listing of Greenland postal codes
+Business::GL::Postalcode - Greenland postal code validator and container
 
 =head1 VERSION
 
@@ -396,7 +400,7 @@ Jonas B. Nielsen, (jonasbn) - C<< <jonasbn@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Business-GL-Postalcode is (C) by Jonas B. Nielsen, (jonasbn) 2014
+Business-GL-Postalcode is (C) by Jonas B. Nielsen, (jonasbn) 2014-2015
 
 Business-GL-Postalcode is released under the artistic license 2.0
 
